@@ -33,8 +33,8 @@ apirevision=''
 apisubversion=''
 apiversion=''
 ar='arm-epoc-pe-ar'
-archlib='/usr/lib/perl/5.13.1/epoc'
-archlibexp='/usr/lib/perl/5.13.1/epoc'
+archlib='/usr/lib/perl/5.13.10/epoc'
+archlibexp='/usr/lib/perl/5.13.10/epoc'
 archname64=''
 archname='epoc'
 archobjs='epoc.o epocish.o epoc_stubs.o'
@@ -424,7 +424,9 @@ d_shmget='undef'
 d_sigaction='undef'
 d_sigprocmask='undef'
 d_sigsetjmp='undef'
+d_sin6_scope_id='undef'
 d_snprintf='undef'
+d_sockaddr_sa_len='undef'
 d_sockatmark='undef'
 d_sockatmarkproto='undef'
 d_socket='define'
@@ -437,6 +439,7 @@ d_sresuproto='undef'
 d_statblks='define'
 d_statfs='undef'
 d_statfsflags='define'
+d_static_inline='undef'
 d_statvfs='undef'
 d_stdio_cnt_lval='define'
 d_stdio_ptr_lval='define'
@@ -752,6 +755,7 @@ passcat=''
 patchlevel=''
 path_sep=':'
 perl=''
+perl_static_inline='static'
 perladmin=''
 perlpath=''
 pg=''
@@ -762,8 +766,8 @@ pmake=''
 pr=''
 prefix=''
 prefixexp=''
-privlib='/usr/lib/perl/5.13.1'
-privlibexp='/usr/lib/perl/5.13.1'
+privlib='/usr/lib/perl/5.13.10'
+privlibexp='/usr/lib/perl/5.13.10'
 procselfexe=''
 prototype='define'
 ptrsize='4'
@@ -822,11 +826,11 @@ sig_num='0'
 sig_num_init='0, 0'
 sig_size='1'
 signal_t='void'
-sitearch='/usr/lib/perl/site_perl/5.13.1/epoc'
-sitearchexp='/usr/lib/perl/site_perl/5.13.1/epoc'
-sitelib='/usr/lib/perl/site_perl/5.13.1/'
+sitearch='/usr/lib/perl/site_perl/5.13.10/epoc'
+sitearchexp='/usr/lib/perl/site_perl/5.13.10/epoc'
+sitelib='/usr/lib/perl/site_perl/5.13.10/'
 sitelib_stem='/usr/lib/perl/site_perl'
-sitelibexp='/usr/lib/perl/site_perl/5.13.1/'
+sitelibexp='/usr/lib/perl/site_perl/5.13.10/'
 siteprefix=''
 siteprefixexp=''
 sizesize='4'
@@ -910,7 +914,7 @@ vendorlib_stem=''
 vendorlibexp=''
 vendorprefix=''
 vendorprefixexp=''
-version='5.13.1'
+version='5.13.10'
 versiononly='undef'
 vi=''
 voidflags='15'
@@ -934,10 +938,10 @@ config_arg10=''
 config_arg11=''
 PERL_REVISION=5
 PERL_VERSION=13
-PERL_SUBVERSION=1
+PERL_SUBVERSION=10
 PERL_API_REVISION=5
 PERL_API_VERSION=13
-PERL_API_SUBVERSION=0
+PERL_API_SUBVERSION=10
 PERL_CONFIG_SH=true
 # Variables propagated from previous config.sh file.
 pp_sys_cflags=''
@@ -1043,7 +1047,7 @@ vendorlib_stem=''
 vendorlibexp=''
 vendorprefix=''
 vendorprefixexp=''
-version='5.13.1'
+version='5.13.10'
 vi=''
 voidflags='15'
 xlibpth=''
@@ -1066,10 +1070,10 @@ config_arg10=''
 config_arg11=''
 PERL_REVISION=5
 PERL_VERSION=13
-PERL_SUBVERSION=1
+PERL_SUBVERSION=10
 PERL_API_REVISION=5
 PERL_API_VERSION=13
-PERL_API_SUBVERSION=0
+PERL_API_SUBVERSION=10
 CONFIGDOTSH=true
 # Variables propagated from previous config.sh file.
 pp_sys_cflags=''
@@ -1167,16 +1171,16 @@ d_SCNfldbl='undef'
 d_perl_otherlibdirs='undef'
 nvsize='16'
 issymlink=''
-installarchlib='/home/of/PERL/perl/lib/5.13.1/epoc'
+installarchlib='/home/of/PERL/perl/lib/5.13.10/epoc'
 installbin='/home/of/PERL/System/Programs/'
 installman1dir='/home/of/PERL/man1'
 installman3dir='/home/of/PERL/man3'
 installprefix=''
 installprefixexp=''
-installprivlib='/home/of/PERL/perl/lib/5.13.1/'
+installprivlib='/home/of/PERL/perl/lib/5.13.10/'
 installscript='/home/of/PERL/bin/'
-installsitearch='/home/of/PERL/site/lib/site_perl/5.13.1/epoc'
-installsitelib='/home/of/PERL/perl/lib/site_perl/5.13.1'
+installsitearch='/home/of/PERL/site/lib/site_perl/5.13.10/epoc'
+installsitelib='/home/of/PERL/perl/lib/site_perl/5.13.10'
 installstyle=''
 installusrbinperl='undef'
 installvendorlib=''
