@@ -3,7 +3,7 @@ package Socket;
 use strict;
 
 our($VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
-$VERSION = "1.93";
+$VERSION = "1.94";
 
 =head1 NAME
 
@@ -282,7 +282,8 @@ The address in a packed string (such as would be returned by pack_sockaddr_in)
 =item canonname => STRING
 
 The canonical name for the host if the C<AI_CANONNAME> flag was provided, or
-C<undef> otherwise.
+C<undef> otherwise. This field will only be present on the first returned
+address.
 
 =back
 
@@ -312,6 +313,9 @@ use warnings::register;
 require Exporter;
 require XSLoader;
 @ISA = qw(Exporter);
+
+# <@Nicholas> you can't change @EXPORT without breaking the implicit API
+# Please put any new constants in @EXPORT_OK!
 @EXPORT = qw(
 	inet_aton inet_ntoa
 	sockaddr_family
@@ -320,7 +324,6 @@ require XSLoader;
 	pack_sockaddr_in6 unpack_sockaddr_in6
 	sockaddr_in sockaddr_in6 sockaddr_un
 	INADDR_ANY INADDR_BROADCAST INADDR_LOOPBACK INADDR_NONE
-	IN6ADDR_ANY IN6ADDR_LOOPBACK
 	AF_802
 	AF_AAL
 	AF_APPLETALK
@@ -483,6 +486,8 @@ require XSLoader;
 	       getaddrinfo
 	       getnameinfo
 
+	       IN6ADDR_ANY IN6ADDR_LOOPBACK
+
 	       AI_CANONNAME
 	       AI_NUMERICHOST
 	       AI_NUMERICSERV
@@ -583,50 +588,55 @@ XSLoader::load();
 
 my %errstr;
 
-if( !defined &getaddrinfo ) {
-   require Scalar::Util;
+if( defined &getaddrinfo ) {
+    # These are not part of the API, nothing uses them, and deleting them
+    # reduces the size of %Socket:: by about 12K
+    delete $Socket::{fake_getaddrinfo};
+    delete $Socket::{fake_getnameinfo};
+} else {
+    require Scalar::Util;
 
-   *getaddrinfo = \&fake_getaddrinfo;
-   *getnameinfo = \&fake_getnameinfo;
+    *getaddrinfo = \&fake_getaddrinfo;
+    *getnameinfo = \&fake_getnameinfo;
 
-   # These numbers borrowed from GNU libc's implementation, but since
-   # they're only used by our emulation, it doesn't matter if the real
-   # platform's values differ
-   my %constants = (
-       AI_PASSIVE     => 1,
-       AI_CANONNAME   => 2,
-       AI_NUMERICHOST => 4,
-       # RFC 2553 doesn't define this but Linux does - lets be nice and
-       # provide it since we can
-       AI_NUMERICSERV => 1024,
+    # These numbers borrowed from GNU libc's implementation, but since
+    # they're only used by our emulation, it doesn't matter if the real
+    # platform's values differ
+    my %constants = (
+	AI_PASSIVE     => 1,
+	AI_CANONNAME   => 2,
+	AI_NUMERICHOST => 4,
+	# RFC 2553 doesn't define this but Linux does - lets be nice and
+	# provide it since we can
+	AI_NUMERICSERV => 1024,
 
-       EAI_BADFLAGS   => -1,
-       EAI_NONAME     => -2,
-       EAI_NODATA     => -5,
-       EAI_FAMILY     => -6,
-       EAI_SERVICE    => -8,
+	EAI_BADFLAGS   => -1,
+	EAI_NONAME     => -2,
+	EAI_NODATA     => -5,
+	EAI_FAMILY     => -6,
+	EAI_SERVICE    => -8,
 
-       NI_NUMERICHOST => 1,
-       NI_NUMERICSERV => 2,
-       NI_NAMEREQD    => 8,
-       NI_DGRAM       => 16,
-   );
+	NI_NUMERICHOST => 1,
+	NI_NUMERICSERV => 2,
+	NI_NAMEREQD    => 8,
+	NI_DGRAM       => 16,
+    );
 
-   foreach my $name ( keys %constants ) {
-      my $value = $constants{$name};
+    foreach my $name ( keys %constants ) {
+	my $value = $constants{$name};
 
-      no strict 'refs';
-      defined &$name or *$name = sub () { $value };
-   }
+	no strict 'refs';
+	defined &$name or *$name = sub () { $value };
+    }
 
-   %errstr = (
-      # These strings from RFC 2553
-      EAI_BADFLAGS()   => "invalid value for ai_flags",
-      EAI_NONAME()     => "nodename nor servname provided, or not known",
-      EAI_NODATA()     => "no address associated with nodename",
-      EAI_FAMILY()     => "ai_family not supported",
-      EAI_SERVICE()    => "servname not supported for ai_socktype",
-   );
+    %errstr = (
+	# These strings from RFC 2553
+	EAI_BADFLAGS()   => "invalid value for ai_flags",
+	EAI_NONAME()     => "nodename nor servname provided, or not known",
+	EAI_NODATA()     => "no address associated with nodename",
+	EAI_FAMILY()     => "ai_family not supported",
+	EAI_SERVICE()    => "servname not supported for ai_socktype",
+    );
 }
 
 # The following functions are used if the system does not have a
@@ -639,151 +649,156 @@ my $REGEXP_IPv4_DOTTEDQUAD = qr/$REGEXP_IPv4_DECIMAL\.$REGEXP_IPv4_DECIMAL\.$REG
 
 sub fake_makeerr
 {
-   my ( $errno ) = @_;
-   my $errstr = $errno == 0 ? "" : ( $errstr{$errno} || $errno );
-   return Scalar::Util::dualvar( $errno, $errstr );
+    my ( $errno ) = @_;
+    my $errstr = $errno == 0 ? "" : ( $errstr{$errno} || $errno );
+    return Scalar::Util::dualvar( $errno, $errstr );
 }
 
 sub fake_getaddrinfo
 {
-   my ( $node, $service, $hints ) = @_;
+    my ( $node, $service, $hints ) = @_;
 
-   $node = "" unless defined $node;
+    $node = "" unless defined $node;
 
-   $service = "" unless defined $service;
+    $service = "" unless defined $service;
 
-   my ( $family, $socktype, $protocol, $flags ) = @$hints{qw( family socktype protocol flags )};
+    my ( $family, $socktype, $protocol, $flags ) = @$hints{qw( family socktype protocol flags )};
 
-   $family ||= Socket::AF_INET(); # 0 == AF_UNSPEC, which we want too
-   $family == Socket::AF_INET() or return fake_makeerr( EAI_FAMILY() );
+    $family ||= Socket::AF_INET(); # 0 == AF_UNSPEC, which we want too
+    $family == Socket::AF_INET() or return fake_makeerr( EAI_FAMILY() );
 
-   $socktype ||= 0;
+    $socktype ||= 0;
 
-   $protocol ||= 0;
+    $protocol ||= 0;
 
-   $flags ||= 0;
+    $flags ||= 0;
 
-   my $flag_passive     = $flags & AI_PASSIVE();     $flags &= ~AI_PASSIVE();
-   my $flag_canonname   = $flags & AI_CANONNAME();   $flags &= ~AI_CANONNAME();
-   my $flag_numerichost = $flags & AI_NUMERICHOST(); $flags &= ~AI_NUMERICHOST();
-   my $flag_numericserv = $flags & AI_NUMERICSERV(); $flags &= ~AI_NUMERICSERV();
+    my $flag_passive     = $flags & AI_PASSIVE();     $flags &= ~AI_PASSIVE();
+    my $flag_canonname   = $flags & AI_CANONNAME();   $flags &= ~AI_CANONNAME();
+    my $flag_numerichost = $flags & AI_NUMERICHOST(); $flags &= ~AI_NUMERICHOST();
+    my $flag_numericserv = $flags & AI_NUMERICSERV(); $flags &= ~AI_NUMERICSERV();
 
-   $flags == 0 or return fake_makeerr( EAI_BADFLAGS() );
+    $flags == 0 or return fake_makeerr( EAI_BADFLAGS() );
 
-   $node eq "" and $service eq "" and return fake_makeerr( EAI_NONAME() );
+    $node eq "" and $service eq "" and return fake_makeerr( EAI_NONAME() );
 
-   my $canonname;
-   my @addrs;
-   if( $node ne "" ) {
-      return fake_makeerr( EAI_NONAME() ) if( $flag_numerichost and $node !~ m/^$REGEXP_IPv4_DOTTEDQUAD$/ );
-      ( $canonname, undef, undef, undef, @addrs ) = gethostbyname( $node );
-      defined $canonname or return fake_makeerr( EAI_NONAME() );
+    my $canonname;
+    my @addrs;
+    if( $node ne "" ) {
+	return fake_makeerr( EAI_NONAME() ) if( $flag_numerichost and $node !~ m/^$REGEXP_IPv4_DOTTEDQUAD$/ );
+	( $canonname, undef, undef, undef, @addrs ) = gethostbyname( $node );
+	defined $canonname or return fake_makeerr( EAI_NONAME() );
 
-      undef $canonname unless $flag_canonname;
-   }
-   else {
-      $addrs[0] = $flag_passive ? Socket::inet_aton( "0.0.0.0" )
-                                : Socket::inet_aton( "127.0.0.1" );
-   }
+	undef $canonname unless $flag_canonname;
+    }
+    else {
+	$addrs[0] = $flag_passive ? Socket::inet_aton( "0.0.0.0" )
+				  : Socket::inet_aton( "127.0.0.1" );
+    }
 
-   my @ports; # Actually ARRAYrefs of [ socktype, protocol, port ]
-   my $protname = "";
-   if( $protocol ) {
-      $protname = getprotobynumber( $protocol );
-   }
+    my @ports; # Actually ARRAYrefs of [ socktype, protocol, port ]
+    my $protname = "";
+    if( $protocol ) {
+	$protname = getprotobynumber( $protocol );
+    }
 
-   if( $service ne "" and $service !~ m/^\d+$/ ) {
-      return fake_makeerr( EAI_NONAME() ) if( $flag_numericserv );
-      getservbyname( $service, $protname ) or return fake_makeerr( EAI_SERVICE() );
-   }
+    if( $service ne "" and $service !~ m/^\d+$/ ) {
+	return fake_makeerr( EAI_NONAME() ) if( $flag_numericserv );
+	getservbyname( $service, $protname ) or return fake_makeerr( EAI_SERVICE() );
+    }
 
-   foreach my $this_socktype ( Socket::SOCK_STREAM(), Socket::SOCK_DGRAM(), Socket::SOCK_RAW() ) {
-      next if $socktype and $this_socktype != $socktype;
+    foreach my $this_socktype ( Socket::SOCK_STREAM(), Socket::SOCK_DGRAM(), Socket::SOCK_RAW() ) {
+	next if $socktype and $this_socktype != $socktype;
 
-      my $this_protname = "raw";
-      $this_socktype == Socket::SOCK_STREAM() and $this_protname = "tcp";
-      $this_socktype == Socket::SOCK_DGRAM()  and $this_protname = "udp";
+	my $this_protname = "raw";
+	$this_socktype == Socket::SOCK_STREAM() and $this_protname = "tcp";
+	$this_socktype == Socket::SOCK_DGRAM()  and $this_protname = "udp";
 
-      next if $protname and $this_protname ne $protname;
+	next if $protname and $this_protname ne $protname;
 
-      my $port;
-      if( $service ne "" ) {
-         if( $service =~ m/^\d+$/ ) {
-            $port = "$service";
-         }
-         else {
-            ( undef, undef, $port, $this_protname ) = getservbyname( $service, $this_protname );
-            next unless defined $port;
-         }
-      }
-      else {
-         $port = 0;
-      }
+	my $port;
+	if( $service ne "" ) {
+	    if( $service =~ m/^\d+$/ ) {
+		$port = "$service";
+	    }
+	    else {
+		( undef, undef, $port, $this_protname ) = getservbyname( $service, $this_protname );
+		next unless defined $port;
+	    }
+	}
+	else {
+	    $port = 0;
+	}
 
-      push @ports, [ $this_socktype, scalar getprotobyname( $this_protname ) || 0, $port ];
-   }
+	push @ports, [ $this_socktype, scalar getprotobyname( $this_protname ) || 0, $port ];
+    }
 
-   my @ret;
-   foreach my $addr ( @addrs ) {
-      foreach my $portspec ( @ports ) {
-         my ( $socktype, $protocol, $port ) = @$portspec;
-         push @ret, {
-            family    => $family,
-            socktype  => $socktype,
-            protocol  => $protocol,
-            addr      => Socket::pack_sockaddr_in( $port, $addr ),
-            canonname => $canonname,
-         };
-      }
-   }
+    my @ret;
+    foreach my $addr ( @addrs ) {
+	foreach my $portspec ( @ports ) {
+	    my ( $socktype, $protocol, $port ) = @$portspec;
+	    push @ret, {
+		family    => $family,
+		socktype  => $socktype,
+		protocol  => $protocol,
+		addr      => Socket::pack_sockaddr_in( $port, $addr ),
+		canonname => undef,
+	    };
+	}
+    }
 
-   return ( fake_makeerr( 0 ), @ret );
+    # Only supply canonname for the first result
+    if( defined $canonname ) {
+	$ret[0]->{canonname} = $canonname;
+    }
+
+    return ( fake_makeerr( 0 ), @ret );
 }
 
 sub fake_getnameinfo
 {
-   my ( $addr, $flags ) = @_;
+    my ( $addr, $flags ) = @_;
 
-   my ( $port, $inetaddr );
-   eval { ( $port, $inetaddr ) = Socket::unpack_sockaddr_in( $addr ) }
-      or return fake_makeerr( EAI_FAMILY() );
+    my ( $port, $inetaddr );
+    eval { ( $port, $inetaddr ) = Socket::unpack_sockaddr_in( $addr ) }
+	or return fake_makeerr( EAI_FAMILY() );
 
-   my $family = Socket::AF_INET();
+    my $family = Socket::AF_INET();
 
-   $flags ||= 0;
+    $flags ||= 0;
 
-   my $flag_numerichost = $flags & NI_NUMERICHOST(); $flags &= ~NI_NUMERICHOST();
-   my $flag_numericserv = $flags & NI_NUMERICSERV(); $flags &= ~NI_NUMERICSERV();
-   my $flag_namereqd    = $flags & NI_NAMEREQD();    $flags &= ~NI_NAMEREQD();
-   my $flag_dgram       = $flags & NI_DGRAM()   ;    $flags &= ~NI_DGRAM();
+    my $flag_numerichost = $flags & NI_NUMERICHOST(); $flags &= ~NI_NUMERICHOST();
+    my $flag_numericserv = $flags & NI_NUMERICSERV(); $flags &= ~NI_NUMERICSERV();
+    my $flag_namereqd    = $flags & NI_NAMEREQD();    $flags &= ~NI_NAMEREQD();
+    my $flag_dgram       = $flags & NI_DGRAM()   ;    $flags &= ~NI_DGRAM();
 
-   $flags == 0 or return fake_makeerr( EAI_BADFLAGS() );
+    $flags == 0 or return fake_makeerr( EAI_BADFLAGS() );
 
-   my $node;
-   if( $flag_numerichost ) {
-      $node = Socket::inet_ntoa( $inetaddr );
-   }
-   else {
-      $node = gethostbyaddr( $inetaddr, $family );
-      if( !defined $node ) {
-         return fake_makeerr( EAI_NONAME() ) if $flag_namereqd;
-         $node = Socket::inet_ntoa( $inetaddr );
-      }
-   }
+    my $node;
+    if( $flag_numerichost ) {
+	$node = Socket::inet_ntoa( $inetaddr );
+    }
+    else {
+	$node = gethostbyaddr( $inetaddr, $family );
+	if( !defined $node ) {
+	    return fake_makeerr( EAI_NONAME() ) if $flag_namereqd;
+	    $node = Socket::inet_ntoa( $inetaddr );
+	}
+    }
 
-   my $service;
-   if( $flag_numericserv ) {
-      $service = "$port";
-   }
-   else {
-      my $protname = $flag_dgram ? "udp" : "";
-      $service = getservbyport( $port, $protname );
-      if( !defined $service ) {
-         $service = "$port";
-      }
-   }
+    my $service;
+    if( $flag_numericserv ) {
+	$service = "$port";
+    }
+    else {
+	my $protname = $flag_dgram ? "udp" : "";
+	$service = getservbyport( $port, $protname );
+	if( !defined $service ) {
+	    $service = "$port";
+	}
+    }
 
-   return ( fake_makeerr( 0 ), $node, $service );
+    return ( fake_makeerr( 0 ), $node, $service );
 }
 
 1;
