@@ -78,13 +78,13 @@ case `$cc -v 2>&1`"" in
 	    ccflags="$cc_cppflags"
 	    if [ "X$gccversion" = "X" ]; then
 		# Done too late in Configure if hinted
-		gccversion=`$cc --version | sed 's/.*(GCC) *//'`
+		gccversion=`$cc -dumpversion`
 		fi
 	    case "$gccversion" in
 		[012]*) # HP-UX and gcc-2.* break UINT32_MAX :-(
 			ccflags="$ccflags -DUINT32_MAX_BROKEN"
 			;;
-               3*)     # GCC (both 32bit and 64bit) will define __STDC_EXT__
+		[34]*) # GCC (both 32bit and 64bit) will define __STDC_EXT__
                        # by default when using GCC 3.0 and newer versions of
                        # the compiler.
                        cppflags="$cc_cppflags"
@@ -94,7 +94,7 @@ case `$cc -v 2>&1`"" in
 		*64*)
 		    echo "main(){}">try.c
 		    case "$gccversion" in
-			3*)
+			[34]*)
 			    case "$archname" in
                                PA-RISC*)
                                    case "$ccflags" in
@@ -136,7 +136,28 @@ case `$cc -v 2>&1`"" in
 		esac
 	    ;;
     *)      ccisgcc=''
-	    ccversion=`which cc | xargs what | awk '/Compiler/{print $2}/Itanium/{print $6,$7}'`
+	    # What cannot be use in combination with ccache links :(
+	    cc_found=""
+	    for p in `echo $PATH | tr : ' ''` ; do
+		x="$p/cc"
+		if [ -f $x ] && [ -x $x ]; then
+		    if [ -h $x ]; then
+			l=`ls -l $x | sed 's,.*-> ,,'`
+			case $l in
+			    /*) x=$l		;;
+			    *)  x="$p/$l"	;;
+			    esac
+			fi
+		    x=`echo $x | sed 's,/\./,/,g'`
+		    case $x in
+			*ccache*) ;;
+			*) [ -z "$cc_found" ] && cc_found=$x ;;
+			esac
+		    fi
+		done
+	    [ -z "$cc_found" ] && cc_found=`which cc`
+	    what $cc_found >&4
+	    ccversion=`what $cc_found | awk '/Compiler/{print $2}/Itanium/{print $6,$7}/for Integrity/{print $6}'`
 	    case "$ccflags" in
                "-Ae "*) ;;
 		*)  ccflags="-Ae $cc_cppflags"
@@ -167,14 +188,17 @@ toke_cflags='ccflags="$ccflags -DARG_ZERO_IS_SCRIPT"'
     gcc_64native=no
 case "$ccisgcc" in
     $define|true|[Yy])
-	echo 'int main(){long l;printf("%d\\n",sizeof(l));}'>try.c
+	echo '#include <stdio.h>\nint main(){long l;printf("%d\\n",sizeof(l));}'>try.c
 	$cc -o try $ccflags $ldflags try.c
 	if [ "`try`" = "8" ]; then
-	    cat <<EOM >&4
+	    case "$use64bitall" in
+		$define|true|[Yy]) ;;
+		*)  cat <<EOM >&4
 
 *** This version of gcc uses 64 bit longs. -Duse64bitall is
 *** implicitly set to enable continuation
 EOM
+		esac
 	    use64bitall=$define
 	    gcc_64native=yes
 	    fi
@@ -194,21 +218,9 @@ case "$archname" in
 	# While here, override so=sl auto-detection
 	so='so'
 	;;
-    *)
-	case "$uselongdouble" in
-	    *) ;;
-	    $define|true|[yY]*)
-		cat <<EOM >&4
-
-*** long doubles are not (yet) supported on HP-UX (any version)
-*** Until it does, we cannot continue, aborting.
-EOM
-		exit 1 ;;
-	    esac
-	;;
     esac
 
-case "$use64bitint" in
+case "$use64bitall" in
     $define|true|[Yy])
 
 	if [ "$xxOsRevMajor" -lt 11 ]; then
@@ -221,12 +233,21 @@ EOM
 	    exit 1
 	    fi
 
+	if [ $xxOsRev -eq 1100 ]; then
+	    # HP-UX 11.00 uses only 48 bits internally in 64bit mode, not 64
+	    # force min/max to 2**47-1
+	    sGMTIME_max=140737488355327
+	    sGMTIME_min=-62167219200
+	    sLOCALTIME_max=140737488355327
+	    sLOCALTIME_min=-62167219200
+	    fi
+
 	# Set libc and the library paths
 	case "$archname" in
 	    PA-RISC*)
 		loclibpth="$loclibpth /lib/pa20_64"
 		libc='/lib/pa20_64/libc.sl' ;;
-	    IA64*) 
+	    IA64*)
 		loclibpth="$loclibpth /usr/lib/hpux64"
 		libc='/usr/lib/hpux64/libc.so' ;;
 	    esac
@@ -248,23 +269,28 @@ EOM
 		# HP-UX soon, including a user-friendly exit
 		case $gcc_64native in
 		    no) case "$gccversion" in
-			    [123]*) ccflags="$ccflags -mlp64"
-				    case "$archname" in
-					PA-RISC*)
-					    ldflags="$ldflags -Wl,+DD64"
-					    ;;
-					IA64*)
-					    ldflags="$ldflags -mlp64"
-					    ;;
-					esac
-				    ;;
+			    [1234]*)
+				ccflags="$ccflags -mlp64"
+				case "$archname" in
+				    PA-RISC*)
+					ldflags="$ldflags -Wl,+DD64"
+					;;
+				    IA64*)
+					ldflags="$ldflags -mlp64"
+					;;
+				    esac
+				;;
 			    esac
 			;;
 		    esac
 		;;
 	    *)
-		ccflags="$ccflags +DD64"
-		ldflags="$ldflags +DD64"
+		case "$use64bitall" in
+		    $define|true|[yY]*)
+			ccflags="$ccflags +DD64"
+			ldflags="$ldflags +DD64"
+			;;
+		    esac
 		;;
 	    esac
 
@@ -283,7 +309,7 @@ EOM
 	case "$archname" in
 	    PA-RISC*)
 		libc='/lib/libc.sl' ;;
-	    IA64*) 
+	    IA64*)
 		loclibpth="$loclibpth /usr/lib/hpux32"
 		libc='/usr/lib/hpux32/libc.so' ;;
 	    esac
@@ -314,13 +340,14 @@ else
 
 ## Optimization limits
 cat >try.c <<EOF
+#include <stdio.h>
 #include <sys/resource.h>
 
 int main ()
 {
     struct rlimit rl;
     int i = getrlimit (RLIMIT_DATA, &rl);
-    printf ("%d\n", rl.rlim_cur / (1024 * 1024));
+    printf ("%d\n", (int)(rl.rlim_cur / (1024 * 1024)));
     } /* main */
 EOF
 $cc -o try $ccflags $ldflags try.c
@@ -339,11 +366,12 @@ to at least 0x08000000 (128 Mb) and rebuild your kernel.
 EOM
 regexec_cflags=''
 doop_cflags=''
+op_cflags=''
     fi
 
 case "$ccisgcc" in
     $define|true|[Yy])
-	
+
 	case "$optimize" in
 	    "")           optimize="-g -O" ;;
 	    *O[3456789]*) optimize=`echo "$optimize" | sed -e 's/O[3-9]/O2/'` ;;
@@ -388,15 +416,25 @@ case "$ccisgcc" in
 	    *)      opt="$optimize"
 		    ;;
 	    esac
+	case "$archname" in
+	    IA64*)
+		case "$ccversion" in
+		    B3910B*A.06.0[12345])
+			# > cc --version
+			# cc: HP aC++/ANSI C B3910B A.06.05 [Jul 25 2005]
+			# Has optimizing problems with -O2 and up for both
+			# maint (5.8.8+) and blead (5.9.3+)
+			# -O1/+O1 passed all tests (m)'05 [ 10 Jan 2005 ]
+			optimize="$opt"			;;
+		    *)  doop_cflags="optimize=\"$opt\""
+			op_cflags="optimize=\"$opt\""	;;
+		    esac
+		;;
+	    esac
 	if [ $maxdsiz -le 64 ]; then
 	    toke_cflags="$toke_cflags;optimize=\"$opt\""
 	    regexec_cflags="optimize=\"$opt\""
 	    fi
-	case "$archname" in
-	    IA64*)
-		doop_cflags="optimize=\"$opt\""
-		;;
-	    esac
 	ld=/usr/bin/ld
 	cccdlflags='+Z'
 	lddlflags='-b +vnocompatwarnings'
@@ -409,7 +447,7 @@ if [ $xxOsRev -lt 1020 ]; then
     fi
 
 #case "$uselargefiles-$ccisgcc" in
-#    "$define-$define"|'-define') 
+#    "$define-$define"|'-define')
 #	cat <<EOM >&4
 #
 #*** I'm ignoring large files for this build because
@@ -473,7 +511,7 @@ EOF
 EOCBU
 
 cat >UU/uselargefiles.cbu <<'EOCBU'
-# This script UU/uselargefiles.cbu will get 'called-back' by Configure 
+# This script UU/uselargefiles.cbu will get 'called-back' by Configure
 # after it has prompted the user for whether to use large files.
 case "$uselargefiles" in
     ""|$define|true|[yY]*)
@@ -500,7 +538,7 @@ EOCBU
 
 # THREADING
 
-# This script UU/usethreads.cbu will get 'called-back' by Configure 
+# This script UU/usethreads.cbu will get 'called-back' by Configure
 # after it has prompted the user for whether to use threads.
 cat >UU/usethreads.cbu <<'EOCBU'
 case "$usethreads" in
@@ -568,7 +606,7 @@ pthread_h_first="$define"
 		    localtime_r_proto='REENTRANT_PROTO_I_TS'
 
 		    # Avoid the poisonous conflicting (and irrelevant)
-		    # prototypes of setkey(). 
+		    # prototypes of setkey ().
 		    i_crypt="$undef"
 
 		    # CMA redefines select to cma_select, and cma_select
@@ -608,32 +646,24 @@ EOM
 	    set `echo X "$libswanted "| sed -e 's/ c / pthread c /'`
 	    shift
 	    libswanted="$*"
-	    fi
 
+	    # HP-UX 11.X seems to have no easy
+	    # way of detecting these *time_r protos.
+	    d_gmtime_r_proto='define'
+	    gmtime_r_proto='REENTRANT_PROTO_S_TS'
+	    d_localtime_r_proto='define'
+	    localtime_r_proto='REENTRANT_PROTO_S_TS'
+	    fi
 	;;
     esac
 EOCBU
 
-# The mysterious io_xs memory corruption in 11.00 32bit seems to get
-# fixed by not using Perl's malloc.  Flip side is performance loss.
-# So we want mymalloc for all situations possible
-usemymalloc='y'
-case "$usethreads" in
-    $define|true|[yY]*) usemymalloc='n' ;;
-    *)  case "$ccisgcc" in
-           $undef|false|[nN]*)
-               case "$use64bitint" in
-                   $undef|false|[nN]*)
-                       case "$ccflags" in
-                           *-DDEBUGGING*) ;;
-                           *) usemymalloc='n' ;;
-                           esac
-                       ;;
-                   esac
-               ;;
-           esac
-       ;;
-    esac
+# There used to be:
+#  The mysterious io_xs memory corruption in 11.00 32bit seems to get
+#  fixed by not using Perl's malloc.  Flip side is performance loss.
+#  So we want mymalloc for all situations possible
+# That set usemymalloc to 'n' for threaded builds and non-gcc 32bit
+#  non-debugging builds and 'y' for all others
 
 usemymalloc='n'
 case "$useperlio" in
@@ -642,10 +672,17 @@ case "$useperlio" in
 
 # malloc wrap works
 case "$usemallocwrap" in
-'') usemallocwrap='define' ;;
-esac
+    '') usemallocwrap='define' ;;
+    esac
 
-# fpclassify() is a macro, the library call is Fpclassify
+# ctime_r () and asctime_r () seem to have issues for versions before
+# HP-UX 11
+if [ $xxOsRevMajor -lt 11 ]; then
+    d_ctime_r="$undef"
+    d_asctime_r="$undef"
+    fi
+
+# fpclassify () is a macro, the library call is Fpclassify
 # Similarly with the others below.
 d_fpclassify='define'
 d_isnan='define'
